@@ -8,6 +8,7 @@ from .iothub_configuration_manager import IoTHubConfigurationManager
 from .iothub_job_manager import IoTHubJobManager
 from .iothub_http_runtime_manager import IoTHubHttpRuntimeManager
 from .iothub_amqp_client import IoTHubAmqpClient
+from .digital_twin_client import DigitalTwinClient
 
 __all__ = [
     "IoTHubRegistryManager",
@@ -15,4 +16,5 @@ __all__ = [
     "IoTHubJobManager",
     "IoTHubHttpRuntimeManager",
     "IoTHubAmqpClient",
+    "DigitalTwinClient",
 ]
